@@ -7,7 +7,7 @@ from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
 from .config import get_config_value
 from .exceptions import LoginException, UploadException
 from .constants import UNHANDLED_EXCEPTION_MSG
-from .helper import ProgressBar
+from .helper import ProgressBar, print_error_tag
 
 DEBUG = os.environ.get("SHIPPY_DEBUG", default=0)
 
@@ -26,7 +26,8 @@ def get_server_version(server_url):
     if r.status_code == 200:
         return r.json()['version']
     else:
-        print("Warning: failed to retrieve server version information!")
+        print_error_tag()
+        print("Failed to retrieve server version information!")
         return None
 
 
@@ -163,7 +164,9 @@ def upload_exception_check(r, build_file):
     elif r.status_code == 401:
         if r.json()['error'] == "insufficient_permissions":
             raise UploadException("You are not allowed to upload for this device!")
-    elif r.status_code[0] == 5:
+    elif r.status_code == 404:
+        raise UploadException("Generic upload error. Make sure your device exists within shipper (contact an admin!)")
+    elif int(r.status_code / 100) == 5:
         raise UploadException("Something went wrong with the server. Please contact the admins.")
 
     undef_response_exp(r)
