@@ -19,4 +19,18 @@ Please check the following:
   2. Please do not rename the build artifacts.
 
 If you believe this is a problem with shippy, please contact maintainer support.
-"""
\ No newline at end of file
+"""
+
+UNHANDLED_EXCEPTION_MSG = """
+shippy crashed for an unknown reason. :(
+To figure out what went wrong, please pass along the full output.
+----
+URL of request: {}
+Request response code: {}
+Request response: {}
+---
+"""
+
+# Defaults
+DEFAULT_SHIPPY_CHUNKED_UPLOAD = "true"
+DEFAULT_SHIPPY_CHUNKED_UPLOAD_SIZE = 10_000_000  # 10 MB
